@@ -38,7 +38,7 @@
 #' list component
 #'
 #' \item \code{session_times}: the session start and end times
-#' correspoding to the columns of each list component
+#' corresponding to the columns of each list component
 #'
 #' \item \code{unit_reference_sport}: the sport where the units have
 #' been inherited from
@@ -311,16 +311,23 @@ plot.distrProfile <- function(x, session = NULL,
     }
     ## duration unit; sport does not matter here as units have been uniformised already
     units <- get_units(x)
+    un <- collect_units(units)
     duration_unit <- units$unit[units$sport == "running" & units$variable == "duration"]
     ## fortify
     df <- fortify(x, melt = TRUE)
     df$Series <- as.numeric(sapply(strsplit(as.character(df$Series), "session"), function(x) x[2]))
     df$Profile <- factor(df$Profile)
+
     ## make basic plot and facets
     lab_data <- function(series) {
-        thisunit <- units$unit[units$sport == "running" & units$variable == series]
+        el <- series == "cumulative_elevation_gain"
+        if (el) series <- "altitude"
+        thisunit <- un$unit[un$variable == series]
         prettyUnit <- prettifyUnits(thisunit)
-        paste0(series, " [", prettyUnit,"]")
+        if (el)
+            paste0("cumulative_elevation_gain", "\n[", prettyUnit,"]")
+        else
+            paste0(series, "\n[", prettyUnit,"]")
     }
     lab_data <- Vectorize(lab_data)
     if (multiple) {
